@@ -1,7 +1,7 @@
 __version__ = "v1.0"
-__copyright__ = "Copyright 2023"
+__copyright__ = "Copyright 2022"
 __license__ = "MIT"
-__lab__ = "cribbslab"
+__lab__ = "Adam Cribbs lab"
 
 from resimpy.read.umi.Library import library as liblogginger
 from resimpy.read.inf.Pseudo import pseudo as seqpseudo
