@@ -1,13 +1,13 @@
 __version__ = "v1.0"
-__copyright__ = "Copyright 2023"
+__copyright__ = "Copyright 2022"
 __license__ = "MIT"
-__lab__ = "cribbslab"
+__lab__ = "Adam Cribbs lab"
 
 import argparse
 from resimpy.simulate.dispatcher.single.General import general as simugeneral
 
 
-class general():
+class general(object):
 
     def __init__(self,
                  mode,
@@ -439,7 +439,6 @@ class general():
 
 
 def run():
-    print(123123123132)
     from pyfiglet import Figlet
     vignette1 = Figlet(font='standard')
     print(vignette1.renderText('Resimpy Toolkit'))
