@@ -1,7 +1,7 @@
 __version__ = "v1.0"
-__copyright__ = "Copyright 2023"
+__copyright__ = "Copyright 2022"
 __license__ = "MIT"
-__lab__ = "cribbslab"
+__lab__ = "Adam Cribbs lab"
 
 import argparse
 from resimpy.simulate.dispatcher.single.SingleCell import singleCell as simusc
